package edu.nyu.scps.widgets;

import android.app.Activity;
import android.content.Context;
import android.os.Bundle;
import android.view.KeyEvent;
import android.view.View;
import android.view.View.OnKeyListener;
import android.view.inputmethod.InputMethodManager;
import android.widget.Button;
import android.widget.CheckBox;
import android.widget.EditText;
import android.widget.RadioButton;
import android.widget.RatingBar;
import android.widget.SeekBar;
import android.widget.TextView;
import android.widget.Toast;
import android.widget.ToggleButton;

public class WidgetsActivity extends Activity {
	/** Called when the activity is first created. */
	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.main);

		final Button button = (Button)findViewById(R.id.button);

		button.setOnClickListener(new View.OnClickListener() {
			@Override
			public void onClick(View v) {
				Toast.makeText(WidgetsActivity.this, "Button pressed", Toast.LENGTH_SHORT).show();
			}
		});

		final ToggleButton toggleButton = (ToggleButton)findViewById(R.id.toggleButton);

		toggleButton.setOnClickListener(new View.OnClickListener() {
			@Override
			public void onClick(View v) {
				boolean b = ((ToggleButton)v).isPressed();
				String s = b ? "Toggled on" : "Toggled off";
				Toast.makeText(WidgetsActivity.this, s, Toast.LENGTH_SHORT).show();
			}
		});

		final CheckBox checkBox = (CheckBox)findViewById(R.id.checkBox);

		checkBox.setOnClickListener(new View.OnClickListener() {
			@Override
			public void onClick(View v) {
				boolean b = ((CheckBox)v).isChecked();
				String s = b ? "Checked" : "Unchecked";
				Toast.makeText(WidgetsActivity.this, s, Toast.LENGTH_SHORT).show();
			}
		});

		//This listener will be the listener for all three radio buttons.

		final View.OnClickListener radioListener = new View.OnClickListener() {
			@Override
			public void onClick(View v) {
				RadioButton radioButton = (RadioButton)v;
				Toast.makeText(WidgetsActivity.this, radioButton.getText(), Toast.LENGTH_SHORT).show();
			}
		};

		final RadioButton radioButton0 = (RadioButton)findViewById(R.id.radioButton0);
		radioButton0.setOnClickListener(radioListener);

		final RadioButton radioButton1 = (RadioButton)findViewById(R.id.radioButton1);
		radioButton1.setOnClickListener(radioListener);

		final RadioButton radioButton2 = (RadioButton)findViewById(R.id.radioButton2);
		radioButton2.setOnClickListener(radioListener);

		final SeekBar seekBar = (SeekBar)findViewById(R.id.seekBar);
		final TextView textView = (TextView)findViewById(R.id.textView);

		//Must implement all three methods, whether you want them or not.

		seekBar.setOnSeekBarChangeListener(new SeekBar.OnSeekBarChangeListener() {
			@Override
			public void onProgressChanged(SeekBar seekBar, int progress, boolean fromUser) {
				textView.setText(Integer.toString(progress));
			}

			@Override
			public void onStartTrackingTouch(SeekBar seekBar) {
			}

			@Override
			public void onStopTrackingTouch(SeekBar seekBar) {
			}
		});

		final EditText editText = (EditText)findViewById(R.id.editText);

		editText.setOnKeyListener(new OnKeyListener() {

			//Return true if no further action is required.
			@Override
			public boolean onKey(View v, int keyCode, KeyEvent event) {

				//If the event is a key-down event on the "enter" key
				//(the arrow pointing down and then left)

				if (event.getAction() == KeyEvent.ACTION_DOWN
					&& keyCode == KeyEvent.KEYCODE_ENTER) {

					//Dismiss the keyboard that popped up.
					InputMethodManager inputMethodManager =
						(InputMethodManager)getSystemService(Context.INPUT_METHOD_SERVICE);
					inputMethodManager.hideSoftInputFromWindow(editText.getWindowToken(), 0);
 
					Toast.makeText(WidgetsActivity.this, editText.getText(), Toast.LENGTH_SHORT).show();
					textView.setText(editText.getText());

					//Do not insert the character into the EditText.
					return true;
				}

				//Insert the character into the EditText.
				return false;
			}
		});

		final RatingBar ratingBar = (RatingBar)findViewById(R.id.ratingBar);

		ratingBar.setOnRatingBarChangeListener(new RatingBar.OnRatingBarChangeListener() {
			@Override
			public void onRatingChanged(RatingBar ratingBar, float rating, boolean fromUser) {
				Toast.makeText(WidgetsActivity.this, "New Rating: " + rating, Toast.LENGTH_SHORT).show();
			}
		});
	}
}